'use strict';

var isSelectorHasDir = function isSelectorHasDir() {
    var selector = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !!selector.match(/^html\[dir(=".+")?\]/);
};

var isHtmlSelector = function isHtmlSelector() {
    var selector = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !!selector.match(/^html/);
};

var isRootSelector = function isRootSelector() {
    var selector = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !!selector.match(/:root/);
};

var addDirToSelectors = function addDirToSelectors() {
    var selectors = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    var dir = arguments[1];

    var prefix = void 0;

    switch (dir) {
        case 'ltr':
        case 'rtl':
            prefix = '[dir="' + dir + '"]';
            break;
        default:
            prefix = '[dir]';
    }

    selectors = selectors.split(/\s*,\s*/).map(function (selector) {
        if (isHtmlSelector(selector)) {
            selector = selector.replace(/html/ig, 'html' + prefix);
        } else if (isRootSelector(selector)) {
            selector = selector.replace(/:root/ig, prefix + ':root');
        } else {
            selector = 'html' + prefix + ' ' + selector;
        }
        return selector;
    }).join(', ');

    return selectors;
};

module.exports = {
    isSelectorHasDir: isSelectorHasDir,
    isHtmlSelector: isHtmlSelector,
    isRootSelector: isRootSelector,
    addDirToSelectors: addDirToSelectors
};